PCB Environment: ActionCache< Data > Class Template Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Types | Public Member Functions
ActionCache< Data > Class Template Reference

## Public Types
using | Ref = Action::CacheRef
using | List = std::list<std::pair<Ref, Data>>

## Public Member Functions
| ActionCache (uint size, uint maxOversize)
Data * | load (Ref)
void | store (Ref, const Data &)
void | clear ()
void | shrink ()

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/ActionCache.hpp